pub(crate) type WnafBase<C> = WnafBase<ProjectivePoint<C>, U5>;Expand description
WnafBase generic around an elliptic curve C using default window size for this curve.
Aliased Type
pub(crate) struct WnafBase<C> { /* private fields */ }pub(crate) type WnafBase<C> = WnafBase<ProjectivePoint<C>, U5>;WnafBase generic around an elliptic curve C using default window size for this curve.
pub(crate) struct WnafBase<C> { /* private fields */ }